==> istio-model-v1beta1-6.7.1-sources.jar: io/fabric8/istio/api/networking/v1beta1/StringMatchExactBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StringMatchExactBuilder extends StringMatchExactFluentImpl<StringMatchExactBuilder> implements VisitableBuilder<StringMatchExact,StringMatchExactBuilder>{
  public StringMatchExactBuilder() {
    this(false);
  }
  public StringMatchExactBuilder(Boolean validationEnabled) {
    this(new StringMatchExact(), validationEnabled);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent) {
    this(fluent, false);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StringMatchExact(), validationEnabled);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent,StringMatchExact instance) {
    this(fluent, instance, false);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent,StringMatchExact instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withExact(instance.getExact());
    }
    this.validationEnabled = validationEnabled; 
  }
  public StringMatchExactBuilder(StringMatchExact instance) {
    this(instance,false);
  }
  public StringMatchExactBuilder(StringMatchExact instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withExact(instance.getExact());
    }
    this.validationEnabled = validationEnabled; 
  }
  StringMatchExactFluent<?> fluent;
  Boolean validationEnabled;
  public StringMatchExact build() {
    StringMatchExact buildable = new StringMatchExact(fluent.getExact());
    return buildable;
  }
  
}

==> istio-model-v1beta1-6.8.0-sources.jar: io/fabric8/istio/api/networking/v1beta1/StringMatchExactBuilder.java <==
package io.fabric8.istio.api.networking.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class StringMatchExactBuilder extends StringMatchExactFluent<StringMatchExactBuilder> implements VisitableBuilder<StringMatchExact,StringMatchExactBuilder>{
  public StringMatchExactBuilder() {
    this(false);
  }
  public StringMatchExactBuilder(Boolean validationEnabled) {
    this(new StringMatchExact(), validationEnabled);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent) {
    this(fluent, false);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new StringMatchExact(), validationEnabled);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent,StringMatchExact instance) {
    this(fluent, instance, false);
  }
  public StringMatchExactBuilder(StringMatchExactFluent<?> fluent,StringMatchExact instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new StringMatchExact());

    if (instance != null) {
      fluent.withExact(instance.getExact());
      fluent.withExact(instance.getExact());
    }
    this.validationEnabled = validationEnabled; 
  }
  public StringMatchExactBuilder(StringMatchExact instance) {
    this(instance,false);
  }
  public StringMatchExactBuilder(StringMatchExact instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new StringMatchExact());

    if (instance != null) {
      this.withExact(instance.getExact());
      this.withExact(instance.getExact());
    }
    this.validationEnabled = validationEnabled; 
  }
  StringMatchExactFluent<?> fluent;
  Boolean validationEnabled;
  public StringMatchExact build() {
    StringMatchExact buildable = new StringMatchExact(fluent.getExact());
    return buildable;
  }
  
}
